class Skills():

  def __init__(self, speed=100):
    self.speed = speed

  # Set new default speed
  def setSpeed(self, newSpeed):
    self.speed = newSpeed
    print("Amsel CLI uses now %s as default speed" % self.speed)

  # Get the current default speed
  def getSpeed(self, newSpeed):
    return self.speed
    print("Amsel CLI uses %s as default speed" % self.speed)

  # Define movement functions.for
  def forward(self, speed=0):
    if not speed: speed = self.speed
    endpoint = "/forward?speed=%s" % speed
    response = self.get(endpoint)

  def backward(self, speed=0):
    if not speed: speed = self.speed
    endpoint = "/reverse?speed=%s" % speed
    response = self.get(endpoint)
    print(response.status)

  def left(self, speed=0):
    if not speed: speed = self.speed
    endpoint = "/left?speed=%s" % speed
    response = self.get(endpoint)
    print(response.status)

  def right(self, speed=0):
    if not speed: speed = self.speed
    endpoint = "/right?speed=%s" % speed
    response = self.get(endpoint)
    print(response.status)

  # Stop movement
  def stop(self):
    endpoint = "/stop"
    response = self.get(endpoint)
    print(response.status)

  # Set amsel to sleep for a certain amount of time
  def sleep(self, duration=0):
    time.sleep(duration)



import http.client

class Connection():

  def __init__(self, local_ip):
    self.local_ip = local_ip
    self.local_address = "amsel.local"

  # Set IP
  def use(self, newIP):
    self.local_ip = newIP
    print("Amsel CLI uses %s as IP" % self.local_ip)

  # Return IP
  def IP(self):
    print("Amsel CLI uses %s as IP" % self.local_ip)
    return self.local_ip

  # Return address
  def address(self):
    print("Amsel CLI uses %s as network address" % self.local_address)
    return self.local_address

  # Establish http connection to device
  def enableHTTPConnection(self, ip):
    return httplib.HTTPConnection(ip)

  # Perform get request and return status
  def get(self, path):
    connection = self.enableHTTPConnection(self.local_ip)
    connection.request("HEAD", path)
    response = connection.getresponse()
    return response



from .connection import Connection
from .skills import Skills
import time

class Amsel(Connection, Skills):
  
  # Constructor
  def __init__(self, local_ip="192.168.0.100"):
    Connection.__init__(self, local_ip)
    Skills.__init__(self)

  # Standard return method
  def __str__(self):
    return "A warm 'Griass di!' from Amsel!"
